@@ -20,16 +20,22 @@ class TestGtkIconTheme < Test::Unit::TestCase
   def test_contexts
     only_gtk_version(2, 12)
 
-    assert_operator(@theme.contexts, :include?, "MimeTypes")
+    assert do
+      @theme.contexts.include?("MimeTypes")
+    end
   end
 
   class TestIcons < self
     def test_no_argument
-      assert_operator(@theme.icons, :include?, "face-cool")
+      assert do
+        @theme.icons.include?("face-cool")
+      end
     end
 
     def test_context
-      assert_operator(@theme.icons("Actions"), :include?, "find")
+      assert do
+        @theme.icons("Emotes").any? {|name| name.start_with?("face-cool")}
+      end
     end
   end
 end
